module.exports = {
  description: 'Blueprint for @choiceform/ui-foundation',

  normalizeEntityName(entityName) {
    return entityName;
  },

  afterInstall: function(options) {
    const isAddon = options.project.isEmberCLIAddon();

    const targetName = isAddon ? 'addon' : 'app';
    this.ui.writeInfoLine(`Installing dependencies for ${targetName} ...`);
    this.ui.writeInfoLine(`正在为 ${targetName} 安装依赖...`);

    const bpOptions = { save: isAddon };
    return this.addAddonsToProject({
      packages: [
        'ember-cli-autoprefixer',
        'ember-cli-dependency-checker',
        'ember-decorators',
        'ember-qunit-decorators',
      ],
    })
      .then(() =>
        this.addAddonToProject({ name: 'ember-css-modules', bpOptions })
      )
      .then(() => this.addAddonToProject({ name: 'ember-lifeline', bpOptions }))
      .then(() =>
        this.addAddonToProject({ name: 'ember-cli-typescript', bpOptions })
      )
      .then(() =>
        this.removePackagesFromProject([
          { name: 'ember-cli-eslint' },
          { name: 'ember-cli-template-lint' },
          { name: 'ember-cli-typescript-blueprints' },
        ])
      )
      .then(() =>
        this.addPackagesToProject([
          { name: '@typescript-eslint/parser' },
          { name: '@typescript-eslint/eslint-plugin' },
          { name: 'ember-template-lint' },
          { name: 'eslint' },
          { name: 'eslint-config-prettier' },
          { name: 'eslint-plugin-prettier' },
          { name: 'eslint-plugin-qunit' },
          { name: 'prettier' },
        ])
      )
      .then(() => {
        this.ui.writeLine(`For ${targetName} usage, please run:`);
        this.ui.writeLine(`用于 ${targetName}，请运行：`);
        this.ui.writeInfoLine(`ember generate foundation-for-${targetName}`);
      });
  },
};
